package com.huiju.estateagents.controller;

import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.entity.TaShareChildRecord;
import com.huiju.estateagents.service.ITaShareActivityService;
import com.huiju.estateagents.service.ITaShareChildRecordService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;

/**
 * <p>
    *   前端控制器
    * </p>
 *
 * @author jobob
 * @since 2019-10-18
 */
@RestController
@RequestMapping("/api")
public class TaShareChildRecordController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaShareChildRecordController.class);

    @Autowired
    private ITaShareChildRecordService iTaShareChildRecordService;
    @Autowired
    private ITaShareActivityService iTaShareActivityService;

    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/taShareChildRecord",method= RequestMethod.GET)
    public ResponseBean taShareChildRecordList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                               @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                               @RequestParam(value ="groupActivityId",required = false) Integer groupActivityId,
                                               @RequestParam(value ="status",required = false) Integer status,
                                               HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean = iTaShareChildRecordService.getList(pageNum, pageSize, groupActivityId, status, getOrgId(request));
            responseBean.addSuccess(responseBean);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taShareChildRecordList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param taShareChildRecord 实体对象
     * @return
     */
    @RequestMapping(value="/admin/taShareChildRecord",method= RequestMethod.POST)
    public ResponseBean taShareChildRecordAdd(@RequestBody TaShareChildRecord taShareChildRecord, HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean = iTaShareChildRecordService.validateRule(taShareChildRecord);
            if (responseBean.getCode() != 0){
                return responseBean;
            }
            //0拼团成功 1拼团中 2拼团失败
            taShareChildRecord.setStatus(1);
            //0未核销 1已核销
            taShareChildRecord.setVerificationStatus(0);
            taShareChildRecord.setOrgId(getOrgId(request));
            if (iTaShareChildRecordService.save(taShareChildRecord)){
                responseBean.addSuccess(taShareChildRecord);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taShareChildRecordAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/taShareChildRecord/{id}", method= RequestMethod.DELETE)
    public ResponseBean taShareChildRecordDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTaShareChildRecordService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taShareChildRecordDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taShareChildRecord 实体对象
     * @return
     */
    @RequestMapping(value="/taShareChildRecord/{id}",method= RequestMethod.PUT)
    public ResponseBean taShareChildRecordUpdate(@PathVariable Integer id,
                                        @RequestBody TaShareChildRecord taShareChildRecord){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaShareChildRecordService.updateById(taShareChildRecord)){
                responseBean.addSuccess(taShareChildRecord);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taShareChildRecordUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taShareChildRecord/{id}",method= RequestMethod.GET)
    public ResponseBean taShareChildRecordGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaShareChildRecordService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taShareChildRecordDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
